.. _analysis:


High Level Analysis Interface
=============================

The high level interface for Gammapy provides a high level Python API for the
most common use cases identified in the analysis process. The classes and
methods included may be used in Python scripts, notebooks or as commands within
IPython sessions. The high level user interface could also be used to automatise
processes driven by parameters declared in a configuration file in YAML format
that addresses the most common analysis use cases identified. It exposes a subset of
the functionality that is available in the sub-packages to support
standard analysis use case in a convenient way.


Using gammapy.analysis
----------------------

.. minigallery::
    :add-heading: Examples using `~gammapy.analysis.Analysis`

    ../examples/tutorials/analysis-1d/spectral_analysis_hli.py
    ../examples/tutorials/analysis-2d/modeling_2D.py
    ../examples/tutorials/analysis-2d/ring_background.py
    ../examples/tutorials/analysis-3d/analysis_3d.py
    ../examples/tutorials/analysis-time/light_curve.py
    ../examples/tutorials/starting/analysis_1.py
